summaryrefslogtreecommitdiffstats
path: root/pytdeconfig.py
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-26 13:14:34 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-26 13:14:34 -0600
commit57e2ced52bf3ba886bb7710212167a86e20305e6 (patch)
treee08b1e82e83f5afa861dc9eeb833dc4bd593900b /pytdeconfig.py
parentccad7a42d96879251c4971e51aac269f61a0ccf8 (diff)
downloadpytde-57e2ced52bf3ba886bb7710212167a86e20305e6.tar.gz
pytde-57e2ced52bf3ba886bb7710212167a86e20305e6.zip
Rename a number of libraries and executables to avoid conflicts with KDE4
Diffstat (limited to 'pytdeconfig.py')
-rw-r--r--pytdeconfig.py10
1 files changed, 5 insertions, 5 deletions
diff --git a/pytdeconfig.py b/pytdeconfig.py
index fe44ff0..e3f5fb8 100644
--- a/pytdeconfig.py
+++ b/pytdeconfig.py
@@ -38,7 +38,7 @@ _pkg_config = {
'libdir': 'lib',
'pytde_kde_sip_flags': '-t ALL -x TQt_STYLE_WINDOWSXP -x TQt_STYLE_INTERLACE -x TQt_STYLE_WINDOWSXP -x TQt_SIP_PRE_4_7_2 -x VendorID -t WS_X11 -t TQt_3_3_6 -t KDE_3_5_3',
'pytde_mod_dir': '/usr/lib/python2.5/site-packages',
- 'pytde_modules': 'dcop tdecore tdefx tdeui kio kresources kabc kutils kfile kparts khtml kspell tdeprint kmdi',
+ 'pytde_modules': 'dcop tdecore tdefx tdeui kio tderesources kabc tdeutils kfile tdeparts tdehtml tdespell tdeprint tdemdi',
'pytde_sip_dir': '/usr/share/sip',
'pytde_version': 0x031000,
'pytde_version_str': '3.16.0'
@@ -169,7 +169,7 @@ class KfileModuleMakefile(KioModuleMakefile):
KioModuleMakefile.finalise(self)
class KpartsModuleMakefile(KfileModuleMakefile):
"""The Makefile class for modules that %Import kparts.
"""
def finalise(self):
"""Finalise the macros.
@@ -178,12 +178,12 @@ class KpartsModuleMakefile(KfileModuleMakefile):
# Note that we don't use self.extra_lib_dirs because we don't want
# it to be added to the rpath.
self.LIBDIR.append(self.config.pyqt_mod_dir)
- self.extra_libs.append(self.module_as_lib("kparts"))
+ self.extra_libs.append(self.module_as_lib("tdeparts"))
KfileModuleMakefile.finalise(self)
class KhtmlModuleMakefile(KpartsModuleMakefile):
"""The Makefile class for modules that %Import khtml.
"""
def finalise(self):
"""Finalise the macros.
@@ -192,7 +192,7 @@ class KhtmlModuleMakefile(KpartsModuleMakefile):
# Note that we don't use self.extra_lib_dirs because we don't want
# it to be added to the rpath.
self.LIBDIR.append(self.config.pyqt_mod_dir)
- self.extra_libs.append(self.module_as_lib("khtml"))
+ self.extra_libs.append(self.module_as_lib("tdehtml"))
KpartsModuleMakefile.finalise(self)
@@ -169,7 +169,7 @@ class KfileModuleMakefile(KioModuleMakefile):
KioModuleMakefile.finalise(self)
class KpartsModuleMakefile(KfileModuleMakefile):
- """The Makefile class for modules that %Import kparts.
+ """The Makefile class for modules that %Import tdeparts.
"""
def finalise(self):
@@ -178,12 +178,12 @@ class KpartsModuleMakefile(KfileModuleMakefile):
KfileModuleMakefile.finalise(self)
class KhtmlModuleMakefile(KpartsModuleMakefile):
- """The Makefile class for modules that %Import khtml.
+ """The Makefile class for modules that %Import tdehtml.
"""
def finalise(self):